@@ -1010,7 +1010,7 @@ sub main
         }
       continue
         {
-          push @log_msg_lines, $line;
+          push @log_msg_lines, $line if ! ref $line;
         }
     }
 
@@ -1030,15 +1030,13 @@ sub main
   $fail
     and exit 1;
 
-  my @non_ref_log_msg_lines = grep { ! ref $_ } @log_msg_lines;
-
   # Collect diffs of non-ChangeLog files.
   # But don't print diff output unless we're sure everything is ok.
   my $diff_lines = get_diffs $vc, \@affected_files;
 
   cross_check $vc, \@affected_files, $diff_lines;
 
-  print join ("\n", @non_ref_log_msg_lines), "\n";
+  print join ("\n", @log_msg_lines), "\n";
   print join ("\n", @$diff_lines), "\n";
 
   # FIXME: add an option to take ChangeLog-style lines from a file,
@@ -1165,6 +1163,27 @@ Generate debug output.
 
 =back
 
+=head1  EXAMPLE
+
+Here's how to use B<@@ME@@> in a project that does not version-control
+a ChangeLog file.  Create a repository just for your personal
+ChangeLog file and make a symlink to it from the top-level directory
+of the project.  For projects that use git, I put this tiny
+auxiliary repository in a directory named .git/c.  You can
+use this bash/zsh alias to set it up and to create the symlink:
+
+    git-changelog-symlink-init()
+    {
+        local d=.git/c
+        test -d .git || return 1
+        mkdir $d
+        touch $d/ChangeLog
+        (cd $d && git init && git add ChangeLog && git commit -m. -a)
+        ln --backup -s $d/ChangeLog .
+    }
+
+
+
 =head1  RESTRICTIONS
 
 This tool can be useful to you only if you use a version control system.
